/*! @file pictures.c
 * @brief This file contains pictures to be shown on graphical LCD.
 *
 * @b COPYRIGHT
 * @n Silicon Laboratories Confidential
 * @n Copyright 2012 Silicon Laboratories, Inc.
 * @n http://www.silabs.com
 */

#include "..\bsp.h"

/** NOTE: the picture description arrays are generated by Fntcvtr.exe 
 **		  The first element of the array should be number of the vertical pixels / 8.	
 **		  The second element of the array should be the number of horizontal pixels.	
 **/

/*
 * INFO icon
horizontal size is 21 pixels.
vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(info21x8[], U8, SEG_CODE) = {
1,21,
'\xff',
'\x81',
'\xff',
'\x81',
'\xfb',
'\xf7',
'\xef',
'\xdf',
'\x81',
'\xff',
'\x81',
'\xf5',
'\xf5',
'\xfd',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xbd',
'\xc3',
'\xff'
}; /* end of char *info21x8 */

/*
 * RSSI icon
horizontal size is 23 pixels.
vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi_icon[], U8, SEG_CODE) = {
1,23,
'\xff',
'\x81',
'\xed',
'\xed',
'\xed',
'\x93',
'\xff',
'\xdb',
'\xb5',
'\xb5',
'\xb5',
'\xcf',
'\xff',
'\xdb',
'\xb5',
'\xb5',
'\xb5',
'\xcf',
'\xff',
'\xbd',
'\x81',
'\xbd',
'\xff',
}; /* end of char *info21x8 */

/*
NO PACKET ICON
  horizontal size is 11 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(no_packet11x8[], U8, SEG_CODE) = {
1,11,
'\x10',
'\x10',
'\x10',
'\x00',
'\x10',
'\x10',
'\x10',
'\x00',
'\x10',
'\x10',
'\x10'
};

/*
RSSI1 ICON
  horizontal size is 2 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi12x8[], U8, SEG_CODE) = {
1,2,
'\x40',
'\x40'
};

/*
RSSI2 ICON
  horizontal size is 4 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi24x8[], U8, SEG_CODE) = {
1,4,
'\x40',
'\x40',
'\x60',
'\x60'
};

/*
RSSI3 ICON
  horizontal size is 6 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi36x8[], U8, SEG_CODE) = {
1,6,
'\x40',
'\x40',
'\x60',
'\x60',
'\x70',
'\x70'
};

/*
RSSI4 ICON
  horizontal size is 8 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi48x8[], U8, SEG_CODE) = {
1,8,
'\x40',
'\x40',
'\x60',
'\x60',
'\x70',
'\x70',
'\x78',
'\x78'
};

/*
RSSI5 ICON
  horizontal size is 10 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi510x8[], U8, SEG_CODE) = {
1,10,
'\x40',
'\x40',
'\x60',
'\x60',
'\x70',
'\x70',
'\x78',
'\x78',
'\x7c',
'\x7c'
};

/*
RSSI6 ICON
  horizontal size is 12 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi612x8[], U8, SEG_CODE) = {
1,12,
'\x40',
'\x40',
'\x60',
'\x60',
'\x70',
'\x70',
'\x78',
'\x78',
'\x7c',
'\x7c',
'\x7e',
'\x7e'
};

/*
RSSI7 ICON
  horizontal size is 14 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi714x8[], U8, SEG_CODE) = {
1,14,
'\x40',
'\x40',
'\x60',
'\x60',
'\x70',
'\x70',
'\x78',
'\x78',
'\x7c',
'\x7c',
'\x7e',
'\x7e',
'\x7f',
'\x7f'
};

/*
ANTENNA ICON
  horizontal size is 9 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(ant9x8[], U8, SEG_CODE) = {
1,9,
'\x01',
'\x02',
'\x04',
'\x7f',
'\x04',
'\x02',
'\x01',
'\x00',
'\x24'
};

/*
RSSI FULL ICON
  horizontal size is 14 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rssi_full_inverted14x8[], U8, SEG_CODE) = {
1,14,
'\x40',
'\x40',
'\x60',
'\x60',
'\x70',
'\x70',
'\x78',
'\x78',
'\x7c',
'\x7c',
'\x7e',
'\x7e',
'\x7f',
'\x7f'
};

/*
ANTANNA 1 ICON
  horizontal size is 15 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(ant1_inverted15x8[], U8, SEG_CODE) = {
1,15,
'\x7f',
'\x7f',
'\x7d',
'\x7b',
'\x41',
'\x7b',
'\x7d',
'\x7f',
'\x7f',
'\x77',
'\x7b',
'\x41',
'\x7f',
'\x7f',
'\x7f'
};

/*
ANTANNA 2 ICON
  horizontal size is 15 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(ant2_inverted15x8[], U8, SEG_CODE) = {
1,15,
'\x7f',
'\x7f',
'\x7d',
'\x7b',
'\x41',
'\x7b',
'\x7d',
'\x7f',
'\x7f',
'\x5b',
'\x4d',
'\x55',
'\x5b',
'\x7f',
'\x7f'
};

/*
OK ICON
  horizontal size is 21 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(ok_inverted21x8[], U8, SEG_CODE) = {
1,21,
'\x00',
'\x00',
'\xff',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xbd',
'\xc3',
'\xff',
'\xff',
'\x81',
'\xef',
'\xe7',
'\xdb',
'\xbd',
'\xff',
'\xff',
'\x00',
'\x00',
'\x00',
};

/*
RX ICON
  horizontal size is 16 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(rx_inverted16x8[], U8, SEG_CODE) = {
1,16,
'\x7f',
'\x7f',
'\x7f',
'\x41',
'\x75',
'\x75',
'\x4b',
'\x7f',
'\x7f',
'\x5d',
'\x6b',
'\x77',
'\x6b',
'\x5d',
'\x7f',
'\x7f'
};

/*
START OFF ICON
  horizontal size is 29 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(start_inverted29x8[], U8, SEG_CODE) = {
1,29,
'\xff',
'\xbb',
'\xb5',
'\xb5',
'\xb5',
'\xcd',
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\x83',
'\xed',
'\xed',
'\x83',
'\xff',
'\x81',
'\xed',
'\xed',
'\x93',
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff'
};

/*
STOP ICON
  horizontal size is 24 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(stop_inverted24x8[], U8, SEG_CODE) = {
1,24,
'\xff',
'\xff',
'\xbb',
'\xb5',
'\xb5',
'\xb5',
'\xcd',
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xc3',
'\xff',
'\x81',
'\xed',
'\xed',
'\xf3',
'\xff'
};

/*
TX ICON
  horizontal size is 16 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(tx_inverted16x8[], U8, SEG_CODE) = {
1,16,
'\x7f',
'\x7f',
'\x7d',
'\x7d',
'\x41',
'\x7d',
'\x7d',
'\x7f',
'\x7f',
'\x5d',
'\x6b',
'\x77',
'\x6b',
'\x5d',
'\x7f',
'\x7f'
};

/*
TX ON ICON
  horizontal size is 32 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(txon_inverted32x8[], U8, SEG_CODE) = {
1,32,
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\xbd',
'\xdb',
'\xe7',
'\xe7',
'\xdb',
'\xbd',
'\xff',
'\xff',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xbd',
'\xc3',
'\xff',
'\x81',
'\xfb',
'\xf7',
'\xef',
'\xdf',
'\x81',
'\xff',
'\x00',
'\x00',
'\x00',
};

/*
TX OFF ICON

  horizontal size is 32 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(txoff_inverted32x8[], U8, SEG_CODE) = {
1,32,
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\xbd',
'\xdb',
'\xe7',
'\xe7',
'\xdb',
'\xbd',
'\xff',
'\xff',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xbd',
'\xc3',
'\xff',
'\x81',
'\xf5',
'\xf5',
'\xfd',
'\xff',
'\x81',
'\xf5',
'\xf5',
'\xfd',
'\xff'
};

/*
CLEAR ICON
  horizontal size is 29 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(clear_inverted29x8[], U8, SEG_CODE) = {
1,29,
'\xff',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xbd',
'\xff',
'\x81',
'\xbf',
'\xbf',
'\xbf',
'\xff',
'\x81',
'\xad',
'\xad',
'\xbd',
'\xff',
'\x83',
'\xed',
'\xed',
'\xed',
'\x83',
'\xff',
'\x81',
'\xed',
'\xed',
'\x93',
'\xff',
'\xff'
};

/*
CLEAR ICON
  horizontal size is 27 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(clear_inverted27x8[], U8, SEG_CODE) = {
1,27,
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xbd',
'\xff',
'\x81',
'\xbf',
'\xbf',
'\xbf',
'\xff',
'\x81',
'\xad',
'\xad',
'\xbd',
'\xff',
'\x83',
'\xed',
'\xed',
'\xed',
'\x83',
'\xff',
'\x81',
'\xed',
'\xed',
'\x93',
'\xff',
};

/*
SETTING ICON
  horizontal size is 48 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(setting_inverted48x8[], U8, SEG_CODE) = {
1,48,
'\xff',
'\xff',
'\xbb',
'\xb5',
'\xb5',
'\xb5',
'\xcd',
'\xff',
'\x81',
'\xb5',
'\xb5',
'\xbd',
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\x81',
'\xff',
'\x81',
'\xfb',
'\xf7',
'\xef',
'\xdf',
'\x81',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xad',
'\xcf',
'\xff',
'\xbb',
'\xb5',
'\xb5',
'\xb5',
'\xcd',
'\xff',
'\xff',
'\xff'
};

/*
SETTING ICON
  horizontal size is 45 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(setting_inverted45x8[], U8, SEG_CODE) = {
1,45,
'\xff',
'\xbb',
'\xb5',
'\xb5',
'\xb5',
'\xcd',
'\xff',
'\x81',
'\xb5',
'\xb5',
'\xbd',
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\xfd',
'\xfd',
'\x81',
'\xfd',
'\xfd',
'\xff',
'\x81',
'\xff',
'\x81',
'\xfb',
'\xf7',
'\xef',
'\xdf',
'\x81',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xad',
'\xcf',
'\xff',
'\xbb',
'\xb5',
'\xb5',
'\xb5',
'\xcd',
'\xff',
};

/*
MINUS ICON
  horizontal size is 16 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(minus_inverted16x8[], U8, SEG_CODE) = {
1,16,
'\xff',
'\xff',
'\xff',
'\xff',
'\xff',
'\xe7',
'\xe7',
'\xe7',
'\xe7',
'\xe7',
'\xe7',
'\xff',
'\xff',
'\xff',
'\xff',
'\xff'
};

/*
PLUS ICON
  horizontal size is 16 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(plus_inverted16x8[], U8, SEG_CODE) = {
1,16,
'\xff',
'\xff',
'\xff',
'\xff',
'\xff',
'\xe7',
'\xe7',
'\x81',
'\x81',
'\xe7',
'\xe7',
'\xff',
'\xff',
'\xff',
'\xff',
'\xff'
};

/*
UP_DOWN ICON
  horizontal size is 16 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(up_down_inverted16x8[], U8, SEG_CODE) = {
1,16,
'\xff',
'\xff',
'\xf7',
'\xf3',
'\x81',
'\xf3',
'\xf7',
'\xff',
'\xff',
'\xef',
'\xcf',
'\x81',
'\xcf',
'\xef',
'\xff',
'\xff'
};

/*
GO ICON
  horizontal size is 16 pixels.
  vertical size is 8 pixels.
*/
const SEGMENT_VARIABLE(go_inverted16x8[], U8, SEG_CODE) = {
1,16,
'\xff',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xad',
'\xcf',
'\xff',
'\xff',
'\xc3',
'\xbd',
'\xbd',
'\xbd',
'\xc3',
'\xff',
'\xff'
};

/*
 Silabs LOGO
	horizontal size is 66 pixels.
	vertical size is 30 pixels.
*/
const SEGMENT_VARIABLE(silabs66x30[], U8, SEG_CODE) = {
4, 66,
'\x00','\x00','\x00','\x23',
'\x00','\x00','\x80','\x24',
'\x00','\x00','\x80','\x24',
'\x00','\xe0','\x81','\x18',
'\x00','\xf8','\x01','\x00',
'\x00','\xfc','\x07','\x00',
'\x00','\xfe','\x0f','\x00',
'\x00','\xff','\x8f','\x3f',
'\x80','\xff','\x1f','\x00',
'\x80','\xff','\x1f','\x00',
'\x80','\xff','\x11','\x00',
'\xc0','\xff','\x91','\x3f',
'\xe0','\xff','\x00','\x20',
'\xe0','\xff','\x00','\x20',
'\xf0','\x7c','\x00','\x20',
'\x70','\x70','\x00','\x00',
'\x30','\x70','\x00','\x00',
'\x38','\x70','\x80','\x3f',
'\x18','\x60','\x03','\x00',
'\x18','\x60','\x07','\x00',
'\x1c','\xe0','\x0f','\x00',
'\x0c','\xe0','\x0f','\x00',
'\x0c','\xe0','\x0f','\x1f',
'\x06','\xe0','\x8f','\x20',
'\x06','\xe0','\x8f','\x20',
'\x82','\xe1','\x8f','\x20',
'\xc2','\xe3','\x0f','\x00',
'\xf2','\xe7','\x0f','\x00',
'\xf2','\xe7','\x0f','\x1f',
'\xf3','\xe5','\x8f','\x20',
'\xfb','\xe5','\x8f','\x20',
'\xf9','\xe5','\x0f','\x1f',
'\xfd','\xe5','\x0f','\x00',
'\xfd','\xe4','\x0f','\x00',
'\xfe','\xe4','\x8f','\x3f',
'\xfe','\xe4','\x07','\x06',
'\xfe','\xfc','\x07','\x0c',
'\xfe','\xfc','\x83','\x3f',
'\xfe','\xfc','\x03','\x00',
'\xfe','\xfc','\x01','\x00',
'\xfe','\xf8','\x09','\x00',
'\xfe','\xf0','\x08','\x00',
'\xfe','\x60','\x08','\x00',
'\xfe','\x00','\x08','\x00',
'\xfe','\x00','\x08','\x00',
'\xfe','\x00','\x88','\x3f',
'\xfe','\x00','\x0c','\x20',
'\xfc','\x00','\x06','\x20',
'\xb8','\x00','\x06','\x20',
'\x90','\x01','\x03','\x00',
'\x80','\x01','\x01','\x3f',
'\x80','\x01','\x81','\x04',
'\x80','\xc3','\x81','\x04',
'\x80','\xe7','\x01','\x3f',
'\x80','\xe7','\x00','\x00',
'\xc0','\xff','\x00','\x00',
'\xe2','\x7f','\x80','\x3f',
'\xf2','\x3f','\x80','\x24',
'\xfe','\x3f','\x80','\x24',
'\xfe','\x0f','\x00','\x1b',
'\xfc','\x0f','\x00','\x00',
'\xf8','\x07','\x00','\x00',
'\xf0','\x01','\x00','\x23',
'\xc6','\x00','\x80','\x24',
'\x06','\x00','\x80','\x24',
'\x00','\x00','\x80','\x18' 
}; 

